@@ -1,17 +1,17 @@
 /* ************************************************************************
- * Copyright (C) 2020-2022 Advanced Micro Devices, Inc.
+ * Copyright (C) 2020-2023 Advanced Micro Devices, Inc.
  * ************************************************************************ */
 
-#ifndef HIPSOLVER_VERSION_H_
-#define HIPSOLVER_VERSION_H_
+#ifndef HIPSOLVER_VERSION_H
+#define HIPSOLVER_VERSION_H
 
 /* the configured version and settings
  */
 // clang-format off
-#define hipsolverVersionMajor 1
-#define hipsolverVersionMinor 8
+#define hipsolverVersionMajor 2
+#define hipsolverVersionMinor 0
 #define hipsolverVersionPatch 0
 #define hipsolverVersionTweak 
 // clang-format on
 
-#endif
+#endif /* HIPSOLVER_VERSION_H */
